import machine

from utime import sleep, ticks_us

OSCILLATOR = 0x20
DISPLAY = 0x80
DIGIT = [0x00, 0x02, 0x06, 0x08]

SSEG = {
  0: 0x3F, 1: 0x06, 2: 0x5B, 3: 0x4F, 4: 0x66,
  5: 0x6d, 6: 0x7d, 7: 0x07, 8: 0x7F, 9: 0x67
}

busno = 0x00
address = 0x70
triggerPin = 2
echoPin = 3
buttonPin = 4
mStatus = 0
t0 = 0
t1 = 0

def showDigit(i:int, j:int):
  global i2c
  POINT = [0x00, 0x00, 0x80, 0x00]
  if i in range(4) and j in range(10):
    c = SSEG[j] | POINT[i]  # Dezimalpunkt
    i2c.writeto_mem(address, DIGIT[i], bArr(c))

def sendTrigger():
  global Trigger
  Trigger.off()
  sleep(0.00001)
  Trigger.on()

def echoEvent(pin):
  global t0, t1
  if Echo.value() == 1:
    t0 = ticks_us()
  elif t0 > 0:
    t1 = ticks_us()
    d = round((t1 - t0)*34300/2/100000) # mm
    for i in range(4):
      showDigit(3-i, (d//(10**i))%10)

def bArr(i:int):
  return bytearray(i.to_bytes(1,'big'))

def buttonPress(pin):
  global mStatus
  if mStatus==0 and pin.value()==0:
    mStatus = 1
    sendTrigger()
    mStatus = 0
    
i2c = machine.I2C(busno, sda=machine.Pin(0), scl=machine.Pin(1))
for i in range(0x10):
  i2c.writeto_mem(address, i, bArr(0x00))
i2c.writeto(address, bArr(OSCILLATOR|0x01))
i2c.writeto(address, bArr(DISPLAY|0x01))


Button = machine.Pin(buttonPin, machine.Pin.IN, machine.Pin.PULL_UP)
Trigger = machine.Pin(triggerPin, machine.Pin.OUT, value=1)
Echo = machine.Pin(echoPin, machine.Pin.IN, machine.Pin.PULL_DOWN)
Echo.irq(echoEvent, machine.Pin.IRQ_RISING|machine.Pin.IRQ_FALLING)
Button.irq(buttonPress, machine.Pin.IRQ_FALLING)

